slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNEvaluateFunctionMatVec

Computes the first column of the matrix f(A) for a given matrix A.

### Synopsis

    #include "slepcfn.h"
    PetscErrorCode FNEvaluateFunctionMatVec(FN fn,Mat A,Vec v)

Logically Collective on fn

### Input Parameters

| fn | - the math function context
| A | - matrix on which the function must be evaluated

### Output Parameter

| v | - vector to hold the first column of f(A)

### Notes

This operation is similar to FNEvaluateFunctionMat() but returns only the first column of f(A), hence saving computations in most cases.

### See Also

FNEvaluateFunction(), FNEvaluateFunctionMat(), FNSetMethod()

### Level

advanced

### Location

src/sys/classes/fn/interface/fnbasic.c
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages